@@ -91,7 +91,7 @@ class MinDalle:
             vocab = json.load(f)
         with open(self.merges_path, 'r', encoding='utf8') as f:
             merges = f.read().split("\n")[1:-1]
-        self.tokenizer = TextTokenizer(vocab, merges, is_verbose=self.is_verbose)
+        self.tokenizer = TextTokenizer(vocab, merges)
 
 
     def init_encoder(self):
@@ -144,12 +144,13 @@ class MinDalle:
     def image_from_tokens(
         self,
         grid_size: int,
-        image_tokens: LongTensor
+        image_tokens: LongTensor,
+        is_verbose: bool = False
     ) -> Image.Image:
         if not self.is_reusable: del self.decoder
         if torch.cuda.is_available(): torch.cuda.empty_cache()
         if not self.is_reusable: self.init_detokenizer()
-        if self.is_verbose: print("detokenizing image")
+        if is_verbose: print("detokenizing image")
         images = self.detokenizer.forward(image_tokens).to(torch.uint8)
         if not self.is_reusable: del self.detokenizer
         images = images.reshape([grid_size] * 2 + list(images.shape[1:]))
@@ -165,11 +166,12 @@ class MinDalle:
         grid_size: int,
         row_count: int,
         mid_count: int = None,
-        handle_intermediate_image: Callable[[int, Image.Image], None] = None
+        handle_intermediate_image: Callable[[int, Image.Image], None] = None,
+        is_verbose: bool = False
     ) -> LongTensor:
-        if self.is_verbose: print("tokenizing text")
-        tokens = self.tokenizer.tokenize(text)
-        if self.is_verbose: print("text tokens", tokens)
+        if is_verbose: print("tokenizing text")
+        tokens = self.tokenizer.tokenize(text, is_verbose=is_verbose)
+        if is_verbose: print("text tokens", tokens)
         text_tokens = numpy.ones((2, 64), dtype=numpy.int32)
         text_tokens[0, :2] = [tokens[0], tokens[-1]]
         text_tokens[1, :len(tokens)] = tokens
@@ -178,7 +180,7 @@ class MinDalle:
         if torch.cuda.is_available(): text_tokens = text_tokens.cuda()
 
         if not self.is_reusable: self.init_encoder()
-        if self.is_verbose: print("encoding text tokens")
+        if is_verbose: print("encoding text tokens")
         encoder_state = self.encoder.forward(text_tokens)
         if not self.is_reusable: del self.encoder
         if torch.cuda.is_available(): torch.cuda.empty_cache()
@@ -195,7 +197,7 @@ class MinDalle:
         )
 
         for row_index in range(row_count):
-            if self.is_verbose: 
+            if is_verbose: 
                 print('sampling row {} of {}'.format(row_index + 1, row_count))
             attention_state, image_tokens = self.decoder.decode_row(
                 row_index,
@@ -207,7 +209,7 @@ class MinDalle:
             if mid_count is not None:
                 if ((row_index + 1) * mid_count) % row_count == 0:
                     tokens = image_tokens[:, 1:]
-                    image = self.image_from_tokens(grid_size, tokens)
+                    image = self.image_from_tokens(grid_size, tokens, is_verbose)
                     handle_intermediate_image(row_index, image)
 
         return image_tokens[:, 1:]
@@ -219,7 +221,8 @@ class MinDalle:
         seed: int = -1,
         grid_size: int = 1,
         mid_count: int = None,
-        handle_intermediate_image: Callable[[Image.Image], None] = None
+        handle_intermediate_image: Callable[[Image.Image], None] = None,
+        is_verbose: bool = False
     ) -> Image.Image:
         image_tokens = self.generate_image_tokens(
             text, 
@@ -227,6 +230,7 @@ class MinDalle:
             grid_size, 
             row_count = 16,
             mid_count = mid_count,
-            handle_intermediate_image = handle_intermediate_image
+            handle_intermediate_image = handle_intermediate_image,
+            is_verbose = is_verbose
         )
-        return self.image_from_tokens(grid_size, image_tokens)
\ No newline at end of file
+        return self.image_from_tokens(grid_size, image_tokens, is_verbose)
\ No newline at end of file
